Struct run_script::types::ScriptOptions [−][src]
pub struct ScriptOptions {
pub runner: Option<String>,
pub working_directory: Option<PathBuf>,
pub input_redirection: IoOptions,
pub output_redirection: IoOptions,
pub exit_on_error: bool,
pub print_commands: bool,
pub env_vars: Option<HashMap<String, String>>,
}Expand description
Options available for invoking the script
Fields
runner: Option<String>Defines the requested runner (defaults to cmd in windows and sh for other platforms)
working_directory: Option<PathBuf>The working directory of the invocation
input_redirection: IoOptionsDefault is IoOptions::Inherit
output_redirection: IoOptionsDefault is IoOptions::Pipe (only pipe enables to capture the output)
exit_on_error: boolSets -e flag. Will exit on any error while running the script (not available for windows)
print_commands: boolSets -x flag for printing each script command before invocation (not available for windows)
env_vars: Option<HashMap<String, String>>Environment environment variables to add before invocation
Implementations
Returns new instance