[−][src]Struct run_script::types::ScriptOptions
Options available for invoking the script
Fields
runner: Option<String>Defines the requested runner (defaults to cmd in windows and sh for other platforms)
working_directory: Option<PathBuf>The working directory of the invocation
input_redirection: IoOptionsDefault is IoOptions::Inherit
output_redirection: IoOptionsDefault is IoOptions::Pipe (only pipe enables to capture the output)
exit_on_error: boolSets -e flag. Will exit on any error while running the script (not available for windows)
print_commands: boolSets -x flag for printing each script command before invocation (not available for windows)
env_vars: Option<HashMap<String, String>>Environment environment variables to add before invocation
Implementations
impl ScriptOptions[src]
pub fn new() -> ScriptOptions[src]
Returns new instance