[−][src]Struct run_script::types::ScriptOptions
Options available for invoking the script
Fields
runner: Option<String>Defines the requested runner (defaults to cmd in windows and sh for other platforms)
capture_output: boolFalse to print the output to the parent process, or capture and return the output (default)
exit_on_error: boolSets -e flag. Will exit on any error while running the script (not available for windows)
print_commands: boolSets -x flag for printing each script command before invocation (not available for windows)
Methods
impl ScriptOptions[src]
pub fn new() -> ScriptOptions[src]
Returns new instance