Struct run_script::types::ScriptOptions [−][src]
pub struct ScriptOptions {
pub runner: Option<String>,
pub capture_output: bool,
pub exit_on_error: bool,
pub print_commands: bool,
}Options available for invoking the script
Fields
runner: Option<String>
Defines the requested runner (defaults to cmd in windows and sh for other platforms)
capture_output: bool
False to print the output to the parent process, or capture and return the output (default)
exit_on_error: bool
Sets -e flag. Will exit on any error while running the script (not available for windows)
print_commands: bool
Sets -x flag for printing each script command before invocation (not available for windows)
Methods
impl ScriptOptions[src]
impl ScriptOptionspub fn new() -> ScriptOptions[src]
pub fn new() -> ScriptOptionsReturns new instance